@@ -5,9 +5,9 @@
  *
  * This contains functions needed to generate html output.
  *
- * @copyright 2003-2015 The SquirrelMail Project Team
+ * @copyright 2003-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: html.class.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: html.class.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  */
 
@@ -19,7 +19,10 @@ class html {
     var $tag, $text, $style, $class,  
         $id, $html_el = array(), $javascript, $xtr_prop;
 
-    function html($tag='', $text='', $style ='', $class='', $id='',
+    /**
+     * Constructor (PHP5 style, required in some future version of PHP)
+     */
+    function __construct($tag='', $text='', $style ='', $class='', $id='',
             $xtr_prop = '', $javascript = '') {
         $this->tag = $tag;
         $this->text = $text;
@@ -30,6 +33,14 @@ class html {
         $this->javascript = $javascript;
     }
 
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     */
+    function html($tag='', $text='', $style ='', $class='', $id='',
+            $xtr_prop = '', $javascript = '') {
+       self::__construct($tag, $text, $style, $class, $id, $xtr_prop, $javascript);
+    }
+
     function htmlAdd($el, $last=true) {
         if ($last) {
             $this->html_el[] = $el;
