@@ -6,9 +6,9 @@
  * This file contains functions needed to handle content type headers 
  * (rfc2045) in mime messages.
  *
- * @copyright 2003-2015 The SquirrelMail Project Team
+ * @copyright 2003-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: ContentType.class.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: ContentType.class.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -41,11 +41,11 @@ class ContentType {
     var $properties = '';
 
     /**
-     * Constructor function.
+     * Constructor (PHP5 style, required in some future version of PHP)
      * Prepared type0 and type1 properties
      * @param string $type content type string without auxiliary information
      */
-    function ContentType($type) {
+    function __construct($type) {
         $type = strtolower($type);
         $pos = strpos($type, '/');
         if ($pos > 0) {
@@ -56,5 +56,14 @@ class ContentType {
         }
         $this->properties = array();
     }
+
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     * Prepared type0 and type1 properties
+     * @param string $type content type string without auxiliary information
+     */
+    function ContentType($type) {
+       self::__construct($type);
+    }
 }
 
