@@ -6,9 +6,9 @@
  * This file contains functions needed to handle content disposition headers 
  * in mime messages. See RFC 2183.
  *
- * @copyright 2003-2015 The SquirrelMail Project Team
+ * @copyright 2003-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Disposition.class.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: Disposition.class.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -23,12 +23,20 @@
  */
 class Disposition {
     /**
-     * Constructor function
+     * Constructor (PHP5 style, required in some future version of PHP)
+     * @param string $name
+     */
+    function __construct($name) {
+       $this->name = $name;
+       $this->properties = array();
+    }
+
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
      * @param string $name
      */
     function Disposition($name) {
-       $this->name = $name;
-       $this->properties = array();
+       self::__construct($name);
     }
 
     /**
