@@ -6,9 +6,9 @@
  * This file should contain class needed to handle Language properties in 
  * mime messages. I suspect that it is RFC2231
  *
- * @copyright 2003-2015 The SquirrelMail Project Team
+ * @copyright 2003-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Language.class.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: Language.class.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -23,10 +23,10 @@
  */
 class Language {
     /**
-     * Class constructor
+     * Constructor (PHP5 style, required in some future version of PHP)
      * @param mixed $name
      */
-    function Language($name) {
+    function __construct($name) {
         /** @var mixed */
         $this->name = $name;
         /**
@@ -35,5 +35,13 @@ class Language {
          */
         $this->properties = array();
     }
+
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     * @param string $name
+     */
+    function Language($name) {
+       self::__construct($name);
+    }
 }
 
