@@ -5,9 +5,9 @@
  *
  * This file contains functions needed to handle headers in mime messages.
  *
- * @copyright 2003-2015 The SquirrelMail Project Team
+ * @copyright 2003-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Rfc822Header.class.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: Rfc822Header.class.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -940,7 +940,7 @@ class Rfc822Header {
      *    Looks through this list of addresses and
      *    returns the array index (an integer even
      *    if the array is given with keys of a
-     *    different type) of the *last* matching
+     *    different type) of the first matching
      *    $address found in this message's
      *    TO or CC (or FROM) headers, unless there
      *    is an exact match (meaning that the "personal
@@ -977,10 +977,10 @@ class Rfc822Header {
             $i=0;
             foreach($address as $argument) {
                 $match = $this->findAddress($argument, $use_from, true);
-                if ($match[1]) {
+                if ($match[1]) { // this indicates when the personal information matched
                     return $i;
                 } else {
-                    if (count($match[0]) && !$result) {
+                    if (count($match[0]) && $result === FALSE) {
                         $result = $i;
                     }
                 }
