@@ -15,9 +15,9 @@
  * passwords being leaked to e.g. other system users. Take extra care when
  * the webserver is shared with untrusted users.
  *
- * @copyright 2000-2015 The SquirrelMail Project Team
+ * @copyright 2000-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: config_default.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: config_default.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -587,15 +587,18 @@ $default_use_mdn = true;
  * Identity Controls
  *
  * If you don't want to allow users to change their email address
- * then you can set $edit_identity to false, if you want them to
+ * then you can set $edit_identity to false; if you want them to
  * not be able to change their full name too then set $edit_name
- * to false as well. $edit_name has no effect unless $edit_identity
- * is false;
+ * to false as well. $edit_reply_to likewise controls users' ability
+ * to change their reply-to address. $edit_name and $edit_reply_to
+ * have no effect unless $edit_identity is false;
  * @global bool $edit_identity
  * @global bool $edit_name
+ * @global bool $edit_reply_to
  */
 $edit_identity = true;
 $edit_name = true;
+$edit_reply_to = true;
 
 /**
  * SquirrelMail adds username information to every sent email.
