@@ -5,9 +5,9 @@
  *
  * Address book backend for LDAP server
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: abook_ldap_server.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: abook_ldap_server.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -100,10 +100,11 @@ class abook_ldap_server extends addressbook_backend {
     var $protocol = '';
 
     /**
-     * Constructor. Connects to database
+     * Constructor (PHP5 style, required in some future version of PHP)
+     * Connects to the database
      * @param array connection options
      */
-    function abook_ldap_server($param) {
+    function __construct($param) {
         if(!function_exists('ldap_connect')) {
             $this->set_error('LDAP support missing from PHP');
             return;
@@ -145,6 +146,14 @@ class abook_ldap_server extends addressbook_backend {
         }
     }
 
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     * Connects to the database
+     * @param array connection options
+     */
+    function abook_ldap_server($param) {
+        return self::__construct($param);
+    }
 
     /**
      * Open the LDAP server.
