@@ -3,9 +3,9 @@
 /**
  * abook_local_file.php
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: abook_local_file.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: abook_local_file.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -94,11 +94,11 @@ class abook_local_file extends addressbook_backend {
     /* ========================== Private ======================= */
 
     /**
-     * Constructor
+     * Constructor (PHP5 style, required in some future version of PHP)
      * @param array $param backend options
      * @return bool
      */
-    function abook_local_file($param) {
+    function __construct($param) {
         $this->sname = _("Personal address book");
         $this->umask = Umask();
 
@@ -141,6 +141,15 @@ class abook_local_file extends addressbook_backend {
         }
     }
 
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     * @param array $param backend options
+     * @return bool
+     */
+    function abook_local_file($param) {
+        return self::__construct($param);
+    }
+
     /**
      * Open the addressbook file and store the file pointer.
      * Use $file as the file to open, or the class' own
