@@ -5,9 +5,9 @@
  *
  * Functions require SM_PATH and support of forms.php functions
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 14493 2015-01-19 18:22:19Z pdontthink $
+ * @version $Id: addressbook.php 14642 2017-01-27 20:31:33Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -293,11 +293,20 @@ class AddressBook {
     var $localbackendname = '';
     var $add_extra_field = false;
 
-      // Constructor function.
-    function AddressBook() {
+    /**
+     * Constructor (PHP5 style, required in some future version of PHP)
+     */
+    function __construct() {
         $this->localbackendname = _("Personal address book");
     }
 
+    /**
+     * Constructor (PHP4 style, kept for compatibility reasons)
+     */
+    function AddressBook() {
+        self::__construct();
+    }
+
     /*
      * Return an array of backends of a given type,
      * or all backends if no type is specified.
