@@ -6,9 +6,9 @@
  * This contains all messages, including information, error, and just
  * about any other message you can think of.
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display_messages.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: display_messages.php 14660 2017-06-09 07:35:30Z pdontthink $
  * @package squirrelmail
  */
 
@@ -140,7 +140,7 @@ function error_box($string, $color) {
     }
 
     /* check if the page header has been sent; if not, send it! */
-    if(!isset($pageheader_sent) && !$pageheader_sent) {
+    if(!isset($pageheader_sent) || !$pageheader_sent) {
         /* include this just to be sure */
         include_once( SM_PATH . 'functions/page_header.php' );
         displayHtmlHeader($org_title.': '.$err);
