@@ -9,9 +9,9 @@
  * @link http://www.section508.gov/ Section 508
  * @link http://www.w3.org/WAI/ Web Accessibility Initiative (WAI)
  * @link http://www.w3.org/TR/html4/ W3.org HTML 4.01 form specs
- * @copyright 2004-2015 The SquirrelMail Project Team
+ * @copyright 2004-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: forms.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: forms.php 14700 2017-07-06 02:46:14Z pdontthink $
  * @package squirrelmail
  * @subpackage forms
  * @since 1.4.3 and 1.5.1
@@ -129,7 +129,7 @@ function addTextArea($name, $text = '', $cols = 40, $rows = 10, $attr = '') {
     return '<textarea name="'.sm_encode_html_special_chars($name).'" '.
         ($name !== null && strpos($attr, 'id="') === FALSE ? 'id="'.sm_encode_html_special_chars(strtr($name, '[]', '__')).'" ' : ' ').
         'rows="'.(int)$rows .'" cols="'.(int)$cols.'" '.
-        $attr . '>'.sm_encode_html_special_chars($text) ."</textarea>\n";
+        $attr . '>'. "\n" . sm_encode_html_special_chars($text) ."</textarea>\n";
 }
 
 /**
