@@ -6,9 +6,9 @@
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: mailbox_display.php 14496 2015-01-25 01:42:38Z pdontthink $
+ * @version $Id: mailbox_display.php 14696 2017-06-28 21:29:22Z pdontthink $
  * @package squirrelmail
  */
 
@@ -268,13 +268,14 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                         .  '&amp;passed_id='. $msg["ID"]
                         .  '&amp;startMessage='.$start_msg.$searchstr.'"';
                 $td_str .= ' ' .concat_hook_function('subject_link', array($start_msg, $searchstr));
-                if ($subject != $msg['SUBJECT']) {
+                // Nah, it's nice to always have a roll-over
+                //if ($subject != $msg['SUBJECT']) {
                     $title = get_html_translation_table(HTML_SPECIALCHARS);
                     $title = array_flip($title);
                     $title = strtr($msg['SUBJECT'], $title);
                     $title = str_replace('"', "''", $title);
                     $td_str .= " title=\"$title\"";
-                }
+                //}
                 $td_str .= ">$flag$subject$flag_end</a>$bold_end";
                 echo html_tag( 'td', $td_str, 'left', $hlt_color );
                 break;
@@ -727,7 +728,7 @@ function mail_message_listing_beginning ($imapConnection,
                                          $start_msg = 1) {
     global $color, $auto_expunge, $base_uri, $thread_sort_messages,
            $allow_thread_sort, $allow_server_sort, $server_sort_order,
-           $PHP_SELF;
+           $PHP_SELF, $javascript_on;
 
     $php_self = $PHP_SELF;
     /* fix for incorrect $PHP_SELF */
@@ -742,6 +743,25 @@ function mail_message_listing_beginning ($imapConnection,
         $source_url = $php_self;
     }
 
+    if ($javascript_on) {
+        $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+        $form_name = "FormMsgs" . $safe_name;
+        $func_name = "CheckAll" . $safe_name;
+        echo '<script language="JavaScript" type="text/javascript">'
+                . "\n<!-- \n"
+                . "function " . $func_name . "() {\n"
+                . "  var c;\n"
+                . "  for (var i = 0; i < document." . $form_name . ".elements.length; i++) {\n"
+                . "    c = document." . $form_name . ".elements[i];\n"
+                . "    if(c.type == 'checkbox' && c.name.substring(0,3) == 'msg'){\n"
+                . "      c.checked = !c.checked;\n"
+                . "    }\n"
+                . "  }\n"
+                . "}\n"
+                . "//-->\n"
+                . '</script>';
+    }
+
     /*
      * This is the beginning of the message list table.
      * It wraps around all messages
@@ -781,7 +801,7 @@ function mail_message_listing_beginning ($imapConnection,
             echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";
             do_hook('mailbox_display_buttons');
 
-    echo "      </small></td>\n"
+    echo "      </td>\n"
          . html_tag( 'td', '', 'right', '', 'nowrap' );
 
     if (!$auto_expunge) {
@@ -818,7 +838,7 @@ function mail_message_listing_beginning ($imapConnection,
                               . "$sort" . '&amp;start_messages=1&amp;set_thread=' . "$set_thread"
                               . '&amp;mailbox=' . urlencode($mailbox) . '">' . $thread_name
                               . '</a></small>&nbsp;'
-                     , '', '', '' )
+                     , '', '', ' colspan="2" ' )
                  , '', '', '' );
     }
 
@@ -964,23 +984,12 @@ function get_selectall_link($start_msg, $sort) {
     global $checkall, $what, $where, $mailbox, $javascript_on;
     global $PHP_SELF, $PG_SHOWNUM;
 
+    $whitespace_style = ' style="white-space:nowrap" ';
     $result = '';
     if ($javascript_on) {
         $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
         $func_name = "CheckAll" . $safe_name;
-        $form_name = "FormMsgs" . $safe_name;
-        $result = '<script language="JavaScript" type="text/javascript">'
-                . "\n<!-- \n"
-                . "function " . $func_name . "() {\n"
-                . "  for (var i = 0; i < document." . $form_name . ".elements.length; i++) {\n"
-                . "    if(document." . $form_name . ".elements[i].type == 'checkbox'){\n"
-                . "      document." . $form_name . ".elements[i].checked = "
-                . "        !(document." . $form_name . ".elements[i].checked);\n"
-                . "    }\n"
-                . "  }\n"
-                . "}\n"
-                . "//-->\n"
-                . '</script><a href="javascript:void(0)" onClick="' . $func_name . '();">' . _("Toggle All")
+        $result = '<a href="javascript:void(0)" onClick="' . $func_name . '();"' . $whitespace_style . '>' . _("Toggle All")
 /*                . '</script><a href="javascript:' . $func_name . '()">' . _("Toggle All")*/
                 . "</a>\n";
     } else {
@@ -1001,7 +1010,7 @@ function get_selectall_link($start_msg, $sort) {
             $result .= '&amp;where=' . urlencode($where)
                     .  '&amp;what=' . urlencode($what);
         }
-        $result .= "\">";
+        $result .= "\"$whitespace_style>";
 
         if (isset($checkall) && ($checkall == '1')) {
             $result .= _("Unselect All");
@@ -1232,7 +1241,7 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
     if (($prv_str != '') || ($nxt_str != '')) {
         $all_str = "<a href=\"right_main.php?PG_SHOWALL=1"
                  . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                 . ">" . _("Show All") . '</a>';
+                 . "style=\"white-space:nowrap\">" . _("Show All") . '</a>';
     }
 
     /* Last but not least, get the value for the toggle all link. */
@@ -1244,11 +1253,11 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
      * a different approach would be any easier to read. ;)
      */
     $result = '';
-    $result .= ($prv_str != '' ? $prv_str . $spc . $sep . $spc : '');
-    $result .= ($nxt_str != '' ? $nxt_str . $spc . $sep . $spc : '');
+    $result .= ($prv_str != '' ? $prv_str . $spc . $sep . ' ' : '');
+    $result .= ($nxt_str != '' ? $nxt_str . $spc . $sep . ' ' : '');
     $result .= ($pg_str  != '' ? $pg_str : '');
-    $result .= ($all_str != '' ? $sep . $spc . $all_str . $spc : '');
-    $result .= ($result  != '' ? $sep . $spc . $tgl_str: $tgl_str);
+    $result .= ($all_str != '' ? $sep . ' ' . $all_str . $spc : '');
+    $result .= ($result  != '' ? $sep . ' ' . $tgl_str: $tgl_str);
 
     /* If the resulting string is blank, return a non-breaking space. */
     if ($result == '') {
@@ -1319,7 +1328,7 @@ function processSubject($subject, $threadlevel = 0) {
 
 function getMbxList($imapConnection) {
     global $lastTargetMailbox;
-    echo  '         <small>&nbsp;<tt><select name="targetMailbox">';
+    echo  '         &nbsp;<tt><select name="targetMailbox">';
     echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) );
     echo '         </select></tt>&nbsp;';
 }
