@@ -6,9 +6,9 @@
  * Loads preferences from the $username.pref file used by almost
  * every other script in the source directory and alswhere.
  *
- * @copyright 1999-2015 The SquirrelMail Project Team
+ * @copyright 1999-2017 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: load_prefs.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @version $Id: load_prefs.php 14703 2017-07-20 09:37:49Z pdontthink $
  * @package squirrelmail
  */
 
@@ -73,9 +73,10 @@ if (isset($chosen_theme) && $found_theme && (file_exists($chosen_theme))) {
 }
 
 
-if (!defined('download_php')) {
+// "download_php" is found nowhere in the source - this must be some orphaned legacy code
+// if (!defined('download_php')) {
     sqsession_register($theme_css, 'theme_css');
-}
+// }
 
 
 /* Load the user's special folder preferences */
